@@ -1,4 +1,4 @@
-__version__ = "0.0.31"
+__version__ = "0.0.32"
 __keywords__ = ["python cgi apache"]
 
 
@@ -12,8 +12,8 @@ __keywords__ = ["python cgi apache"]
 
 from .core import (
     _SERVER, _GET, _POST, _SESSION, _COOKIE, _HEADERS,
-    set_status, set_header,
-    execute, print, flush, main,
+    set_status, set_header, generate_range_headers,
+    execute, print, print_file, flush, main,
     log, log_construct,
     should_return_304
 )
